==> aws-android-sdk-transcribe-2.22.5-sources.jar: com/amazonaws/services/transcribe/model/transform/ContentRedactionJsonMarshaller.java <==
/*
 * Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.transcribe.model.transform;

import com.amazonaws.services.transcribe.model.*;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO ContentRedaction
 */
class ContentRedactionJsonMarshaller {

    public void marshall(ContentRedaction contentRedaction, AwsJsonWriter jsonWriter)
            throws Exception {
        jsonWriter.beginObject();
        if (contentRedaction.getRedactionType() != null) {
            String redactionType = contentRedaction.getRedactionType();
            jsonWriter.name("RedactionType");
            jsonWriter.value(redactionType);
        }
        if (contentRedaction.getRedactionOutput() != null) {
            String redactionOutput = contentRedaction.getRedactionOutput();
            jsonWriter.name("RedactionOutput");
            jsonWriter.value(redactionOutput);
        }
        jsonWriter.endObject();
    }

    private static ContentRedactionJsonMarshaller instance;

    public static ContentRedactionJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ContentRedactionJsonMarshaller();
        return instance;
    }
}

==> aws-android-sdk-transcribe-2.54.0-sources.jar: com/amazonaws/services/transcribe/model/transform/ContentRedactionJsonMarshaller.java <==
/*
 * Copyright 2010-2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.transcribe.model.transform;

import com.amazonaws.services.transcribe.model.*;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO ContentRedaction
 */
class ContentRedactionJsonMarshaller {

    public void marshall(ContentRedaction contentRedaction, AwsJsonWriter jsonWriter)
            throws Exception {
        jsonWriter.beginObject();
        if (contentRedaction.getRedactionType() != null) {
            String redactionType = contentRedaction.getRedactionType();
            jsonWriter.name("RedactionType");
            jsonWriter.value(redactionType);
        }
        if (contentRedaction.getRedactionOutput() != null) {
            String redactionOutput = contentRedaction.getRedactionOutput();
            jsonWriter.name("RedactionOutput");
            jsonWriter.value(redactionOutput);
        }
        if (contentRedaction.getPiiEntityTypes() != null) {
            java.util.List<String> piiEntityTypes = contentRedaction.getPiiEntityTypes();
            jsonWriter.name("PiiEntityTypes");
            jsonWriter.beginArray();
            for (String piiEntityTypesItem : piiEntityTypes) {
                if (piiEntityTypesItem != null) {
                    jsonWriter.value(piiEntityTypesItem);
                }
            }
            jsonWriter.endArray();
        }
        jsonWriter.endObject();
    }

    private static ContentRedactionJsonMarshaller instance;

    public static ContentRedactionJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ContentRedactionJsonMarshaller();
        return instance;
    }
}
